@@ -163,7 +163,3 @@ class EEValue(float):
     def __rpow__(cls, other):
         res = super(EEValue, cls).__rpow__(other)
         return cls.__class__(res)
-
-
-x = EEValue(10E-12)
-print(x)
\ No newline at end of file
